aboutsummaryrefslogtreecommitdiffstats
path: root/examples/declarative/extending/chapter5-listproperties/listproperties.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/declarative/extending/chapter5-listproperties/listproperties.py')
-rw-r--r--examples/declarative/extending/chapter5-listproperties/listproperties.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/examples/declarative/extending/chapter5-listproperties/listproperties.py b/examples/declarative/extending/chapter5-listproperties/listproperties.py
index dd3e5c65c..466b3aca1 100644
--- a/examples/declarative/extending/chapter5-listproperties/listproperties.py
+++ b/examples/declarative/extending/chapter5-listproperties/listproperties.py
@@ -39,15 +39,15 @@
##
#############################################################################
"""PySide2 port of the qml/tutorials/extending-qml/chapter5-listproperties example from Qt v5.x"""
import os
import sys
-from PySide2.QtCore import Property, QUrl
-from PySide2.QtGui import QGuiApplication, QPen, QPainter, QColor
-from PySide2.QtQml import qmlRegisterType, ListProperty
-from PySide2.QtQuick import QQuickPaintedItem, QQuickView, QQuickItem
+from PySide6.QtCore import Property, QUrl
+from PySide6.QtGui import QGuiApplication, QPen, QPainter, QColor
+from PySide6.QtQml import qmlRegisterType, ListProperty
+from PySide6.QtQuick import QQuickPaintedItem, QQuickView, QQuickItem
class PieSlice (QQuickPaintedItem):
def __init__(self, parent = None):
@@ -39,15 +39,15 @@
##
#############################################################################
-"""PySide2 port of the qml/tutorials/extending-qml/chapter5-listproperties example from Qt v5.x"""
+"""PySide6 port of the qml/tutorials/extending-qml/chapter5-listproperties example from Qt v5.x"""
import os
import sys